summaryrefslogtreecommitdiff
path: root/Master/texmf-dist/tex/luatex/luatexja/ltj-inputbuf.lua
diff options
context:
space:
mode:
Diffstat (limited to 'Master/texmf-dist/tex/luatex/luatexja/ltj-inputbuf.lua')
-rw-r--r--Master/texmf-dist/tex/luatex/luatexja/ltj-inputbuf.lua12
1 files changed, 6 insertions, 6 deletions
diff --git a/Master/texmf-dist/tex/luatex/luatexja/ltj-inputbuf.lua b/Master/texmf-dist/tex/luatex/luatexja/ltj-inputbuf.lua
index cec74cfc232..f8a7b578629 100644
--- a/Master/texmf-dist/tex/luatex/luatexja/ltj-inputbuf.lua
+++ b/Master/texmf-dist/tex/luatex/luatexja/ltj-inputbuf.lua
@@ -8,18 +8,18 @@ luatexja.load_module('charrange'); local ltjc = luatexja.charrange
require("unicode")
local utflen = unicode.utf8.len
local utfbyte = unicode.utf8.byte
+local utfchar = unicode.utf8.char
local node_new = node.new
local node_free = node.free
local id_glyph = node.id('glyph')
-local getcatcode = tex.getcatcode
+local getcatcode, getcount = tex.getcatcode, tex.getcount
local ltjc_is_japanese_char_curlist = ltjc.is_japanese_char_curlist
-local FFFFF = string.char(0xF3,0xBF,0xBF,0xBF)
--- the following function is modified from jafontspec.lua (by K. Maeda).
--- Instead of "%", we use U+FFFFF for suppressing spaces.
--DEBUG require"socket"
local time_line = 0
-local start_time_measure, stop_time_measure
+local start_time_measure, stop_time_measure
= ltjb.start_time_measure, ltjb.stop_time_measure
local function add_comment(buffer)
start_time_measure('inputbuf')
@@ -33,12 +33,12 @@ local function add_comment(buffer)
if c>=0x80 then
local ct = getcatcode(c)
local te = tex.endlinechar
- local ctl = (te ~= -1) and (getcatcode(te)==5) and (getcatcode(0xFFFFF)==14)
+ local ctl = (te ~= -1) and (getcatcode(te)==5) and (getcatcode(getcount('ltjlineendcomment'))==14)
-- Is the catcode of endline character is 5 (end-of-line)?
- -- Is the catcode of U+FFFFF (new comment char) is 14 (comment)?
+ -- Is the catcode of \ltjlineendcomment (new comment char) is 14 (comment)?
if ((ct==11) or (ct==12)) and ctl then
if ltjc_is_japanese_char_curlist(c) then
- buffer = buffer .. FFFFF -- U+FFFFF
+ buffer = buffer .. utfchar(getcount('ltjlineendcomment'))
end
end
end